Crate mecomp_core

source

Modules

Macros

  • This macro returns the name of the enclosing function. As the internal implementation is based on the std::any::type_name, this macro derives all the limitations of this function.

Functions