DaemonSettings

Struct DaemonSettings 

pub struct DaemonSettings {
    pub rpc_port: u16,
    pub library_paths: Box<[PathBuf]>,
    pub artist_separator: OneOrMany<String>,
    pub protected_artist_names: OneOrMany<String>,
    pub genre_separator: Option<String>,
    pub conflict_resolution: MetadataConflictResolution,
    pub log_level: LevelFilter,
}

Fields

rpc_port: u16

The port to listen on for RPC requests. Default is 6600.

library_paths: Box<[PathBuf]>

The root paths of the music library.

artist_separator: OneOrMany<String>

Separators for artist names in song metadata. For example, “Foo, Bar, Baz” would be split into [“Foo”, “Bar”, “Baz”]. if the separator is “, “. If the separator is not found, the entire string is considered as a single artist. If unset, will not split artists.

Users can provide one or many separators, and must provide them as either a single string or an array of strings.

[daemon]
artist_separator = " & "
artist_separator = [" & ", "; "]
...
protected_artist_names: OneOrMany<String>

Exceptions for artist name separation, for example: “Foo & Bar; Baz” would be split into [“Foo”, “Bar”, “Baz”] if the separators are set to “&” and “; “.

However, if the following exception is set:

[daemon]
protected_artist_names = ["Foo & Bar"]

Then the artist “Foo & Bar; Baz” would be split into [“Foo & Bar”, “Baz”].

Note that the exception applies to the entire “name”, so:

[daemon]
protected_artist_names = ["Foo & Bar"]

would split “Foo & Bar” into [“Foo & Bar”], but “Foo & Bar Baz” would still be split into [“Foo”, “Bar Baz”].

genre_separator: Option<String>conflict_resolution: MetadataConflictResolution

how conflicting metadata should be resolved “overwrite” - overwrite the metadata with new metadata “skip” - skip the file (keep old metadata)

log_level: LevelFilter

What level of logging to use. Default is “info”.