pub struct LibraryHealth {
pub artists: usize,
pub albums: usize,
pub songs: usize,
pub unanalyzed_songs: Option<usize>,
pub playlists: usize,
pub collections: usize,
pub orphaned_artists: usize,
pub orphaned_albums: usize,
pub orphaned_playlists: usize,
pub orphaned_collections: usize,
}Expand description
Health information about the library
Fields
artists: usizeThe number of artists in the library
albums: usizeThe number of albums in the library
songs: usizeThe number of songs in the library
unanalyzed_songs: Option<usize>The number of unanalyzed songs in the library Optional because the analysis feature may not be enabled for the daemon
playlists: usizeThe number of playlists in the library
collections: usizeThe number of collections in the library
orphaned_artists: usizeThe number of orphaned songs in the library This is the number of artists that have no songs, and no albums
orphaned_albums: usizeThe number of orphaned albums in the library This is the number of albums that have no songs
orphaned_playlists: usizeThe number of orphaned playlists in the library This is the number of playlists that have no songs
orphaned_collections: usizeThe number of orphaned collections in the library This is the number of collections that have no songs