Modules
Macros
- This macro returns the name of the enclosing function. As the internal implementation is based on the
std::any::type_name, this macro derives all the limitations of this function.
Functions
- Get the config directory for the application.
- Get the data directory for the application.
- Check if a server is already running on localhost on the given port. If a server is already running, return true, otherwise return false.